@@ -2,17 +2,15 @@ use alloc::vec;
 use core::convert::TryInto;
 
 use crate::ross_convert_packet::{RossConvertPacket, RossConvertPacketError};
+use crate::ross_event::ross_event_code::*;
 use crate::ross_event::ross_event_packet::RossEventPacketError;
 use crate::ross_packet::RossPacket;
 
-pub const ROSS_CONFIGURATOR_HELLO_EVENT_CODE: u16 = 0x0005;
-
 #[derive(Debug, PartialEq)]
-pub struct RossConfiguratorHelloEvent {
-}
+pub struct RossConfiguratorHelloEvent {}
 
 impl RossConvertPacket<RossConfiguratorHelloEvent> for RossConfiguratorHelloEvent {
-    fn try_from_packet(packet: RossPacket) -> Result<Self, RossConvertPacketError> {
+    fn try_from_packet(packet: &RossPacket) -> Result<Self, RossConvertPacketError> {
         if packet.data.len() != 2 {
             return Err(RossConvertPacketError::WrongSize);
         }
@@ -33,7 +31,7 @@ impl RossConvertPacket<RossConfiguratorHelloEvent> for RossConfiguratorHelloEven
     }
 
     fn to_packet(&self) -> RossPacket {
-        let mut data = vec!();
+        let mut data = vec![];
 
         for byte in u16::to_be_bytes(ROSS_CONFIGURATOR_HELLO_EVENT_CODE).iter() {
             data.push(*byte);
